
# Mailpapa

```python
import mailpapa

mailpapa.search(company='google', pattern='{first}.{last}@google.com')

```

<https://support.google.com/accounts/answer/6010255>
<https://myaccount.google.com/lesssecureapps>